@@ -3,6 +3,7 @@ import json
 
 from pydantic import create_model, ValidationError
 from pydantic.dataclasses import dataclass
+from pydantic.json import pydantic_encoder
 
 
 def dataclass_to_model(dc):
@@ -13,7 +14,7 @@ def serialize(i, to_string=False):
     if hasattr(i, "__pydantic_model__"):
         j = i.__pydantic_model__(**asdict(i)).json()
     else:
-        j = json.loads(asdict(i))
+        j = json.dumps(asdict(i), default=pydantic_encoder)
     if to_string:
         return j
 
